@@ -667,23 +667,17 @@ ogg_tag_read_file_tag (gchar *filename, File_Tag *FileTag, GError **error)
     filename_utf8 = filename_to_display (filename);
 
     {
-    // Skip the id3v2 tag
+    /* Check for an unsupported ID3v2 tag. */
     guchar tmp_id3[4];
-    gulong id3v2size;
-
-    // Check if there is an ID3v2 tag...
-    if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET, NULL, error))
-    {
-        goto err;
-    }
 
     if (g_input_stream_read (G_INPUT_STREAM (istream), tmp_id3, 4, NULL,
                              error) == 4)
     {
-        // Calculate ID3v2 length
-        if (tmp_id3[0] == 'I' && tmp_id3[1] == 'D' && tmp_id3[2] == '3' && tmp_id3[3] < 0xFF)
+        /* Calculate ID3v2 length. */
+        if (tmp_id3[0] == 'I' && tmp_id3[1] == 'D' && tmp_id3[2] == '3'
+            && tmp_id3[3] < 0xFF)
         {
-            // id3v2 tag skipeer $49 44 33 yy yy xx zz zz zz zz [zz size]
+            /* ID3v2 tag skipper $49 44 33 yy yy xx zz zz zz zz [zz size]. */
             /* Size is 6-9 position */
             if (!g_seekable_seek (G_SEEKABLE (istream), 2, G_SEEK_CUR,
                                   NULL, error))
@@ -694,33 +688,20 @@ ogg_tag_read_file_tag (gchar *filename, File_Tag *FileTag, GError **error)
             if (g_input_stream_read (G_INPUT_STREAM (istream), tmp_id3, 4,
                                      NULL, error) == 4)
             {
-                id3v2size = 10 + ( (long)(tmp_id3[3])        | ((long)(tmp_id3[2]) << 7)
-                                | ((long)(tmp_id3[1]) << 14) | ((long)(tmp_id3[0]) << 21) );
+                gchar *path;
 
-                if (!g_seekable_seek (G_SEEKABLE (istream), id3v2size,
-                                      G_SEEK_SET, NULL, error))
-                {
-                    goto err;
-                }
+                path = g_file_get_path (file);
+                g_debug ("Ogg file '%s' contains an ID3v2 tag", path);
+                g_free (path);
 
-                Log_Print(LOG_ERROR,_("Warning: The Ogg Vorbis file '%s' contains an ID3v2 tag."),filename_utf8);
+                /* Mark the file as modified, so that the ID3 tag is removed
+                 * upon saving. */
+                FileTag->saved = FALSE;
             }
-            else if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET,
-                                       NULL, error))
-            {
-                goto err;
-            }
-
         }
-        else if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET,
-                                   NULL, error))
-        {
-            goto err;
-        }
-
     }
-    else if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET,
-                               NULL, error))
+
+    if (error && *error != NULL)
     {
         goto err;
     }
@@ -762,9 +743,8 @@ ogg_tag_read_file_tag (gchar *filename, File_Tag *FileTag, GError **error)
 err:
     g_assert (error == NULL || *error != NULL);
     g_object_unref (istream);
-    g_object_unref (istream);
     g_object_unref (file);
-    g_free(filename_utf8);
+    g_free (filename_utf8);
     return FALSE;
 }
 
@@ -817,7 +797,6 @@ ogg_tag_write_file_tag (ET_File *ETFile, GError **error)
     gchar          *filename_utf8;
     gchar          *basename_utf8;
     GFile           *file;
-    GFileInputStream *istream;
     vcedit_state   *state;
     vorbis_comment *vc;
     gchar          *string;
@@ -832,81 +811,6 @@ ogg_tag_write_file_tag (ET_File *ETFile, GError **error)
     filename_utf8 = ((File_Name *)ETFile->FileNameCur->data)->value_utf8;
 
     file = g_file_new_for_path (filename);
-    istream = g_file_read (file, NULL, error);
-
-    if (!istream)
-    {
-        g_object_unref (file);
-        return FALSE;
-    }
-
-    {
-    // Skip the id3v2 tag
-    gsize bytes_read;
-    guchar tmp_id3[4];
-    gulong id3v2size;
-
-    // Check if there is an ID3v2 tag...
-    if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET, NULL, error))
-    {
-        goto err;
-    }
-
-    if (g_input_stream_read_all (G_INPUT_STREAM (istream), tmp_id3, 4,
-                                 &bytes_read, NULL, error))
-    {
-        // Calculate ID3v2 length
-        if (tmp_id3[0] == 'I' && tmp_id3[1] == 'D' && tmp_id3[2] == '3' && tmp_id3[3] < 0xFF)
-        {
-            // id3v2 tag skipeer $49 44 33 yy yy xx zz zz zz zz [zz size]
-            /* Size is 6-9 position */
-            if (!g_seekable_seek (G_SEEKABLE (istream), 2, G_SEEK_CUR,
-                                  NULL, error))
-            {
-                goto err;
-            }
-
-            if (g_input_stream_read_all (G_INPUT_STREAM (istream), tmp_id3, 4,
-                                         &bytes_read, NULL, error))
-            {
-                id3v2size = 10 + ( (long)(tmp_id3[3])        | ((long)(tmp_id3[2]) << 7)
-                                | ((long)(tmp_id3[1]) << 14) | ((long)(tmp_id3[0]) << 21) );
-
-                if (!g_seekable_seek (G_SEEKABLE (istream), id3v2size,
-                                      G_SEEK_SET, NULL, error))
-                {
-                    goto err;
-                }
-
-                Log_Print(LOG_ERROR,_("Warning: The Ogg Vorbis file '%s' contains an ID3v2 tag."),filename_utf8);
-            }
-            else
-            {
-                g_debug ("Only %" G_GSIZE_FORMAT " bytes out of 4 bytes of "
-                         "data were read", bytes_read);
-                goto err;
-            }
-
-        }
-        else if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET,
-                                   NULL, error))
-        {
-            goto err;
-        }
-
-    }
-    else
-    {
-        g_debug ("Only %" G_GSIZE_FORMAT " bytes out of 4 bytes of data were "
-                 "read", bytes_read);
-        goto err;
-    }
-
-    }
-
-    g_assert (error == NULL || *error == NULL);
-
-    g_object_unref (istream);
 
     state = vcedit_new_state();    // Allocate memory for 'state'
 
@@ -1027,8 +931,7 @@ ogg_tag_write_file_tag (ET_File *ETFile, GError **error)
                 if (!gdk_pixbuf_loader_write (loader, pic->data, pic->size,
                                               &error))
                 {
-                    Log_Print (LOG_ERROR, _("Error with 'loader_write': %s"),
-                               error->message);
+                    g_debug ("Error parsing image data: %s", error->message);
                     g_error_free (error);
                     g_object_unref (loader);
                     continue;
@@ -1041,9 +944,8 @@ ogg_tag_write_file_tag (ET_File *ETFile, GError **error)
 
                     if (!gdk_pixbuf_loader_close (loader, &error))
                     {
-                        Log_Print (LOG_ERROR,
-                                   _("Error with 'loader_close': %s"),
-                                   error->message);
+                        g_debug ("Error parsing image data: %s",
+                                 error->message);
                         g_error_free (error);
                         g_object_unref (loader);
                         continue;
@@ -1166,11 +1068,5 @@ ogg_tag_write_file_tag (ET_File *ETFile, GError **error)
 
     g_assert (error == NULL || *error == NULL);
     return TRUE;
-    
-err:
-    g_assert (error == NULL || *error != NULL);
-    g_object_unref (istream);
-    g_object_unref (file);
-    return FALSE;
 }
 #endif /* ENABLE_OGG */
